@@ -4,6 +4,7 @@ import os
 import sys
 import unittest
 import xml
+import pickle
 
 import pytest
 
@@ -13,6 +14,8 @@ os_is_nt = os.name in ("nt", "dos", "os2", "ce")
 
 if sys.version_info < (3, 3):
     FileNotFoundError = IOError
+if sys.version_info < (3, 2):
+    unittest.TestCase.assertRegex = unittest.TestCase.assertRegexpMatches
 
 data_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
 
@@ -49,18 +52,15 @@ class MediaInfoTest(unittest.TestCase):
 
 class MediaInfoInvalidXMLTest(unittest.TestCase):
     def setUp(self):
-        if sys.version_info < (2, 7):
-            self._exc_class = xml.parsers.expat.ExpatError
-        else:
-            self._exc_class = xml.etree.ElementTree.ParseError
         with open(os.path.join(data_dir, 'invalid.xml'), 'r') as f:
             self.xml_data = f.read()
     def test_parse_invalid_xml(self):
-        self.assertRaises(self._exc_class, MediaInfo, self.xml_data)
+        self.assertRaises(xml.etree.ElementTree.ParseError, MediaInfo, self.xml_data)
 
 class MediaInfoLibraryTest(unittest.TestCase):
     def setUp(self):
         self.mi = MediaInfo.parse(os.path.join(data_dir, "sample.mp4"))
+        self.non_full_mi = MediaInfo.parse(os.path.join(data_dir, "sample.mp4"), full=False)
     def test_can_parse_true(self):
         self.assertTrue(MediaInfo.can_parse())
     def test_track_count(self):
@@ -73,6 +73,9 @@ class MediaInfoLibraryTest(unittest.TestCase):
         self.assertEqual(self.mi.tracks[2].format, "AAC")
         self.assertEqual(self.mi.tracks[1].duration, 958)
         self.assertEqual(self.mi.tracks[2].duration, 980)
+    def test_full_option(self):
+        self.assertEqual(self.mi.tracks[0].footersize, "59")
+        self.assertEqual(self.non_full_mi.tracks[0].footersize, None)
 
 class MediaInfoUnicodeXMLTest(unittest.TestCase):
     def setUp(self):
@@ -117,25 +120,95 @@ class MediaInfoTestParseNonExistentFile(unittest.TestCase):
 
 class MediaInfoCoverDataTest(unittest.TestCase):
     def setUp(self):
-        self.mi = MediaInfo.parse(
+        self.cover_mi = MediaInfo.parse(
                 os.path.join(data_dir, "sample_with_cover.mp3"),
                 cover_data=True
         )
+        self.no_cover_mi = MediaInfo.parse(
+                os.path.join(data_dir, "sample_with_cover.mp3")
+        )
     def test_parse_cover_data(self):
         self.assertEqual(
-                self.mi.tracks[0].cover_data,
+                self.cover_mi.tracks[0].cover_data,
                 "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAACXBIWXMAAAAAAA"
                 "AAAQCEeRdzAAAADUlEQVR4nGP4x8DwHwAE/AH+QSRCQgAAAABJRU5ErkJggg=="
         )
+    def test_parse_no_cover_data(self):
+        _, lib_version_str, lib_version = MediaInfo._get_library()
+        if lib_version < (18, 3):
+            pytest.skip("Cover_Data option not supported by this library version "
+                "(v{} detected, v18.03 required)".format(lib_version_str)
+            )
+        self.assertEqual(self.no_cover_mi.tracks[0].cover_data, None)
 
 class MediaInfoTrackParsingTest(unittest.TestCase):
     def test_track_parsing(self):
         mi = MediaInfo.parse(os.path.join(data_dir, "issue55.flv"))
         self.assertEqual(len(mi.tracks), 2)
 
-class MediainfoRuntimeErrorTest(unittest.TestCase):
+class MediaInfoRuntimeErrorTest(unittest.TestCase):
     def test_parse_invalid_url(self):
         # This is the easiest way to cause a parsing error
         # since non-existent files return a different exception
         self.assertRaises(RuntimeError, MediaInfo.parse,
                 "unsupportedscheme://")
+
+class MediaInfoSlowParseTest(unittest.TestCase):
+    def setUp(self):
+        self.mi = MediaInfo.parse(
+                os.path.join(data_dir, "vbr_requires_parsespeed_1.mp4"),
+                parse_speed=1
+        )
+    def test_slow_parse_speed(self):
+        self.assertEqual(self.mi.tracks[2].stream_size, "3353 / 45")
+
+class MediaInfoEqTest(unittest.TestCase):
+    def setUp(self):
+        self.mp3_mi = MediaInfo.parse(os.path.join(data_dir, "sample_with_cover.mp3"))
+        self.mp3_other_mi = MediaInfo.parse(os.path.join(data_dir, "sample_with_cover.mp3"))
+        self.mp4_mi = MediaInfo.parse(os.path.join(data_dir, "sample.mp4"))
+    def test_eq(self):
+        self.assertEqual(self.mp3_mi.tracks[0], self.mp3_other_mi.tracks[0])
+        self.assertEqual(self.mp3_mi, self.mp3_other_mi)
+        self.assertNotEqual(self.mp3_mi.tracks[0], self.mp4_mi.tracks[0])
+        self.assertNotEqual(self.mp3_mi, self.mp4_mi)
+    def test_pickle_unpickle(self):
+        pickled_track = pickle.dumps(self.mp4_mi.tracks[0])
+        self.assertEqual(self.mp4_mi.tracks[0], pickle.loads(pickled_track))
+        pickled_mi = pickle.dumps(self.mp4_mi)
+        self.assertEqual(self.mp4_mi, pickle.loads(pickled_mi))
+
+class MediaInfoTextOutputTest(unittest.TestCase):
+    def setUp(self):
+        self.mi = MediaInfo.parse(os.path.join(data_dir, "sample.mp4"), text=True)
+    def test_text_output(self):
+        self.assertRegex(self.mi, r"Stream size\s+: 373836\b")
+
+class MediaInfoLegacyStreamDisplayTest(unittest.TestCase):
+    def setUp(self):
+        self.mi = MediaInfo.parse(os.path.join(data_dir, "aac_he_v2.aac"))
+        self.legacy_mi = MediaInfo.parse(os.path.join(data_dir, "aac_he_v2.aac"), legacy_stream_display=True)
+    def test_legacy_stream_display(self):
+        self.assertEqual(self.mi.tracks[1].channel_s, 2)
+        self.assertEqual(self.legacy_mi.tracks[1].channel_s, "2 / 1 / 1")
+
+class MediaInfoOptionsTest(unittest.TestCase):
+    def setUp(self):
+        _, lib_version_str, lib_version = MediaInfo._get_library()
+        if lib_version < (19, 9):
+            pytest.skip("Reset option not supported by this library version "
+                "(v{} detected, v19.09 required)".format(lib_version_str)
+            )
+        self.raw_language_mi = MediaInfo.parse(
+            os.path.join(data_dir, "sample.mkv"),
+            mediainfo_options={"Language": "raw"},
+        )
+        # Parsing the file without the custom options afterwards
+        # allows us to check that the "Reset" option worked
+        # https://github.com/MediaArea/MediaInfoLib/issues/1128
+        self.normal_mi = MediaInfo.parse(
+            os.path.join(data_dir, "sample.mkv"),
+        )
+    def test_mediainfo_options(self):
+        self.assertEqual(self.normal_mi.tracks[1].other_language[0], "English")
+        self.assertEqual(self.raw_language_mi.tracks[1].language, "en")
